@@ -369,7 +369,7 @@ def predictSingle(imagepath,modeltag = None,classify = None):
         
         if not os.path.exists(imagepath):
             
-            raise Exception("picture is not exists at [{}]".format(imagepath)")
+            raise Exception("picture is not exists at [{}]".format(imagepath))
         
         x = readBmp([imagepath],500,500,"bmp")
         
